@@ -33,6 +33,12 @@
 
 G_BEGIN_DECLS
 
+#define GRL_LOG_DOMAIN_DEFAULT wc_log_domain
+GRL_LOG_DOMAIN_EXTERN(wc_log_domain);
+
+#define GRL_NET_CAPTURE_DIR_VAR "GRL_NET_CAPTURE_DIR"
+
+
 struct _GrlNetWcPrivate {
   SoupSession *session;
   SoupLoggerLogLevel log_level;
@@ -76,6 +82,12 @@ guint cache_get_size (GrlNetWc *self);
 
 void free_op_res (void *op);
 
+G_GNUC_INTERNAL
+void init_dump_directory (void);
+
+G_GNUC_INTERNAL
+void dump_data (SoupURI *uri, const gchar *data, gsize length);
+
 G_END_DECLS
 
 #endif /* _GRL_NET_PRIVATE_H_ */
