@@ -23,6 +23,12 @@ GType grl_resolution_flags_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_RESOLUTION_FLAGS (grl_resolution_flags_get_type())
 GType grl_write_flags_get_type (void) G_GNUC_CONST;
 #define GRL_TYPE_WRITE_FLAGS (grl_write_flags_get_type())
+
+/* enumerations from "data/grl-media.h" */
+GType grl_media_serialize_type_get_type (void) G_GNUC_CONST;
+#define GRL_TYPE_MEDIA_SERIALIZE_TYPE (grl_media_serialize_type_get_type())
+GType grl_media_type_get_type (void) G_GNUC_CONST;
+#define GRL_TYPE_MEDIA_TYPE (grl_media_type_get_type())
 G_END_DECLS
 
 #endif /* _GRL_TYPE_BUILTINS_H_ */
